try:
    from ._version import version as __version__
except ImportError:
    __version__ = "1.0.4"

__all__ = "BacSeg"


class BacSeg:
    pass
